@@ -12,8 +12,8 @@ use strict;
 use warnings;
 
 package Games::Risk::Controller;
-BEGIN {
-  $Games::Risk::Controller::VERSION = '3.112010';
+{
+  $Games::Risk::Controller::VERSION = '3.112410';
 }
 # ABSTRACT: controller poe session for risk
 
@@ -25,6 +25,7 @@ use Games::Risk::I18n      qw{ T };
 use Games::Risk::Map;
 use Games::Risk::Player;
 use Games::Risk::Resources qw{ map_path };
+use Games::Risk::Utils     qw{ debug };
 
 use constant K => $poe_kernel;
 
@@ -59,7 +60,7 @@ sub spawn {
         inline_states => {
             # private events - session management
             _start                  => \&_onpriv_start,
-            _stop                   => sub { warn "GR shutdown\n" },
+            _stop                   => sub { debug( "GR shutdown\n" ) },
             # private events - game states
             _gui_ready              => \&_onpriv_create_players,
             _players_created        => \&_onpriv_assign_countries,
@@ -754,7 +755,7 @@ Games::Risk::Controller - controller poe session for risk
 
 =head1 VERSION
 
-version 3.112010
+version 3.112410
 
 =head1 SYNOPSIS
 
