@@ -12,8 +12,8 @@ use strict;
 use warnings;
 
 package Games::Risk::GUI::GameOver;
-BEGIN {
-  $Games::Risk::GUI::GameOver::VERSION = '3.112010';
+{
+  $Games::Risk::GUI::GameOver::VERSION = '3.112410';
 }
 # ABSTRACT: window used when game is over
 
@@ -22,7 +22,8 @@ use Tk;
 use Tk::Font;
 use Tk::Sugar;
 
-use Games::Risk::I18n qw{ T };
+use Games::Risk::I18n  qw{ T };
+use Games::Risk::Utils qw{ debug };
 
 use constant K => $poe_kernel;
 
@@ -43,7 +44,7 @@ sub spawn {
         args          => [ $args ],
         inline_states => {
             _start       => \&_onpriv_start,
-            _stop        => sub { warn "gui-gameover shutdown\n" },
+            _stop        => sub { debug( "gui-gameover shutdown\n" ) },
             # gui events
             _but_close   => \&_onpriv_but_close,
         },
@@ -139,7 +140,7 @@ Games::Risk::GUI::GameOver - window used when game is over
 
 =head1 VERSION
 
-version 3.112010
+version 3.112410
 
 =head1 DESCRIPTION
 
