@@ -12,20 +12,19 @@ use strict;
 use warnings;
 
 package Games::Risk::Tk::About;
-BEGIN {
-  $Games::Risk::Tk::About::VERSION = '3.112010';
+{
+  $Games::Risk::Tk::About::VERSION = '3.112410';
 }
 # ABSTRACT: prisk about information
 
 use Moose;
 use Path::Class;
-use Tk::Role::Dialog 1.101480;
 
 use Games::Risk;
 use Games::Risk::I18n  qw{ T };
 use Games::Risk::Utils qw{ $SHAREDIR };
 
-with 'Tk::Role::Dialog';
+with 'Tk::Role::Dialog' => { -version => 1.101480 };
 
 
 # -- initialization / finalization
@@ -57,7 +56,7 @@ Games::Risk::Tk::About - prisk about information
 
 =head1 VERSION
 
-version 3.112010
+version 3.112410
 
 =head1 DESCRIPTION
 
